#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-1sNfkobpeTQA75gmVa5Rkl
key:                  ipynb-0.2-1sNfkobpeTQA75gmVa5Rkl
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  e9f7eeffde5a1277a5ab528fc69b5f39
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-1sNfkobpeTQA75gmVa5Rkl
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

